changeset 28620:77f2575e2a91

Rename the "src" parameter in the sws_scale() declaration to "srcSlice" to stress the fact that it references a slice rather than an image.
author stefano
date Wed, 18 Feb 2009 23:16:31 +0000
parents d4d2d83ba82c
children 2464c1a4f2f8
files libswscale/swscale.h
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/libswscale/swscale.h	Wed Feb 18 23:11:47 2009 +0000
+++ b/libswscale/swscale.h	Wed Feb 18 23:16:31 2009 +0000
@@ -131,13 +131,13 @@
                                   SwsFilter *srcFilter, SwsFilter *dstFilter, double *param);
 
 /**
  * Scales the image slice in \p src and puts the resulting scaled
  * slice in the image in \p dst. A slice is a sequence of consecutive
  * rows in an image.
  *
  * @param context   the scaling context previously created with
  *                  sws_getContext()
  * @param src       the array containing the pointers to the planes of
  *                  the source slice
  * @param srcStride the array containing the strides for each plane of
  *                  the source image
@@ -152,7 +152,7 @@
  *                  the destination image
  * @return          the height of the output slice
  */
-int sws_scale(struct SwsContext *context, uint8_t* src[], int srcStride[], int srcSliceY,
+int sws_scale(struct SwsContext *context, uint8_t* srcSlice[], int srcStride[], int srcSliceY,
               int srcSliceH, uint8_t* dst[], int dstStride[]);
 #if LIBSWSCALE_VERSION_MAJOR < 1
 /**
@@ -131,13 +131,13 @@
 
 /**
- * Scales the image slice in \p src and puts the resulting scaled
+ * Scales the image slice in \p srcSlice and puts the resulting scaled
  * slice in the image in \p dst. A slice is a sequence of consecutive
  * rows in an image.
@@ -131,13 +131,13 @@
  * @param context   the scaling context previously created with
  *                  sws_getContext()
- * @param src       the array containing the pointers to the planes of
+ * @param srcSlice  the array containing the pointers to the planes of
  *                  the source slice
  * @param srcStride the array containing the strides for each plane of